==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/sq.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Menaxho Parametrat Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Menaxho Galeria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Gjerësia");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Lartësia");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image Gjerësia");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Lartësia");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ruajtur Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Shfaq Titujt");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Renditur");
define('MANAGE_GALLERY_DELETE_IMAGE', "Fshij Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Ruaj Rendit Në Radhë");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliko &#39;Update&#39; për të publikuar <br /> imazhet tuaja ngarkuar.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Të gjitha imazhet janë ridimensionuar dhe settings janë ruajtur.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Pati një gabim duke ndryshuar imazhet ose të kursyer cilësimet.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imazhi juaj (s) ka qenë i ngarkuar së fundi.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Pati një gabim gjatë ngarkimit imazhin tuaj (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Skedari jeni duke u përpjekur të ngarkoj nuk është një imazh.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Skedari jeni duke u përpjekur për të ngarkoni është shumë i madh.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titulli është ruajtur.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Jeni te sigurte qe doni te fshini imazhin");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Imazhi është fshirë.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Pati një gabim gjatë fshirjes imazhin.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Ruajtja e parametrave dhe ndryshuar madhësinë e fotove, ju lutem prisni ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Ngarkimi, ju lutem prisni ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Urdhri lloj nuk është ruajtur. A doni për të ruajtur rendin renditjes?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Urdhri image lloj është ruajtur.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Pati një gabim të shpëtuar lloj imazhit.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/sq.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Menaxho Parametrat Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Menaxho Galeria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Gjerësia");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Lartësia");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image Gjerësia");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Lartësia");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ruajtur Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Shfaq Titujt");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Renditur");
define('MANAGE_GALLERY_DELETE_IMAGE', "Fshij Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Ruaj Rendit Në Radhë");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliko &#39;Update&#39; për të publikuar <br /> imazhet tuaja ngarkuar.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Të gjitha imazhet janë ridimensionuar dhe settings janë ruajtur.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Pati një gabim duke ndryshuar imazhet ose të kursyer cilësimet.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imazhi juaj (s) ka qenë i ngarkuar së fundi.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Pati një gabim gjatë ngarkimit imazhin tuaj (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Skedari jeni duke u përpjekur të ngarkoj nuk është një imazh.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Skedari jeni duke u përpjekur për të ngarkoni është shumë i madh.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titulli është ruajtur.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Jeni te sigurte qe doni te fshini imazhin");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Imazhi është fshirë.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Pati një gabim gjatë fshirjes imazhin.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Ruajtja e parametrave dhe ndryshuar madhësinë e fotove, ju lutem prisni ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Ngarkimi, ju lutem prisni ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Urdhri lloj nuk është ruajtur. A doni për të ruajtur rendin renditjes?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Urdhri image lloj është ruajtur.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Pati një gabim të shpëtuar lloj imazhit.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Skedari që po përpiqeni të ngarkoni është më i madh se cilësimet &#39;upload_max_filesize&#39; ose &#39;post_max_size&#39; PHP. Kontaktoni administratorin e sistemit tuaj për të rritur këto kufij.");
?>
